@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-
 """
 Run classification with CLD2.
 
@@ -20,7 +18,7 @@ import lidtk.classifiers
 class CLD2Classifier(lidtk.classifiers.LIDClassifier):
     """LID with the CLD-2 classifier."""
 
-    def predict(self, text):
+    def predict(self, text: str) -> str:
         """
         Predicting the language of a text.
 
