@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-
 """Convert a language pickle file to a txt."""
 
 # Core Library modules
@@ -8,16 +6,16 @@ import glob
 import pickle
 
 
-def main():
+def main() -> None:
     """Convert all pickle language files to txt files."""
     lang_files = glob.glob("lang/*.pickle")
     for lang_file in lang_files:
         lang = lang_file.split("/")[-1].split(".")[0]
-        target_path = "lang_txt/{}.txt".format(lang)
+        target_path = f"lang_txt/{lang}.txt"
         convert(lang_file, target_path)
 
 
-def convert(source_path, target_path):
+def convert(source_path: str, target_path: str) -> None:
     """
     Convert a single pickle language files to a txt file.
 
